##  Introduction
Okta enables organizations to securely manage user authentication and access to applications and for developers to build identity controls into applications, website web services, and devices.
Okta is a valuable source for discovery as it allows for the discovery of services and users, but also to discover employee and department data.
